import * as iam from '@aws-cdk/aws-iam';
import * as sns from '@aws-cdk/aws-sns';
import * as sfn from '@aws-cdk/aws-stepfunctions';
import { Construct } from 'constructs';
/**
 * The data type set for the SNS message attributes.
 *
 * @see https://docs.aws.amazon.com/sns/latest/dg/sns-message-attributes.html#SNSMessageAttributes.DataTypes
 * @stability stable
 */
export declare enum MessageAttributeDataType {
    /**
     * Strings are Unicode with UTF-8 binary encoding.
     *
     * @stability stable
     */
    STRING = "String",
    /**
     * An array, formatted as a string.
     *
     * @see https://docs.aws.amazon.com/sns/latest/dg/sns-message-attributes.html#SNSMessageAttributes.DataTypes
     * @stability stable
     */
    STRING_ARRAY = "String.Array",
    /**
     * Numbers are positive or negative integers or floating-point numbers.
     *
     * @see https://docs.aws.amazon.com/sns/latest/dg/sns-message-attributes.html#SNSMessageAttributes.DataTypes
     * @stability stable
     */
    NUMBER = "Number",
    /**
     * Binary type attributes can store any binary data.
     *
     * @see https://docs.aws.amazon.com/sns/latest/dg/sns-message-attributes.html#SNSMessageAttributes.DataTypes
     * @stability stable
     */
    BINARY = "Binary"
}
/**
 * A message attribute to add to the SNS message.
 *
 * @see https://docs.aws.amazon.com/sns/latest/dg/sns-message-attributes.html
 * @stability stable
 */
export interface MessageAttribute {
    /**
     * The value of the attribute.
     *
     * @stability stable
     */
    readonly value: any;
    /**
     * The data type for the attribute.
     *
     * @default determined by type inspection if possible, fallback is String
     * @see https://docs.aws.amazon.com/sns/latest/dg/sns-message-attributes.html#SNSMessageAttributes.DataTypes
     * @stability stable
     */
    readonly dataType?: MessageAttributeDataType;
}
/**
 * Properties for publishing a message to an SNS topic.
 *
 * @stability stable
 */
export interface SnsPublishProps extends sfn.TaskStateBaseProps {
    /**
     * The SNS topic that the task will publish to.
     *
     * @stability stable
     */
    readonly topic: sns.ITopic;
    /**
     * The message you want to send.
     *
     * With the exception of SMS, messages must be UTF-8 encoded strings and
     * at most 256 KB in size.
     * For SMS, each message can contain up to 140 characters.
     *
     * @stability stable
     */
    readonly message: sfn.TaskInput;
    /**
     * Add message attributes when publishing.
     *
     * These attributes carry additional metadata about the message and may be used
     * for subscription filters.
     *
     * @default {}
     * @see https://docs.aws.amazon.com/sns/latest/dg/sns-message-attributes.html
     * @stability stable
     */
    readonly messageAttributes?: {
        [key: string]: MessageAttribute;
    };
    /**
     * Send different messages for each transport protocol.
     *
     * For example, you might want to send a shorter message to SMS subscribers
     * and a more verbose message to email and SQS subscribers.
     *
     * Your message must be a JSON object with a top-level JSON key of
     * "default" with a value that is a string
     * You can define other top-level keys that define the message you want to
     * send to a specific transport protocol (i.e. "sqs", "email", "http", etc)
     *
     * @default false
     * @see https://docs.aws.amazon.com/sns/latest/api/API_Publish.html#API_Publish_RequestParameters
     * @stability stable
     */
    readonly messagePerSubscriptionType?: boolean;
    /**
     * Used as the "Subject" line when the message is delivered to email endpoints.
     *
     * This field will also be included, if present, in the standard JSON messages
     * delivered to other endpoints.
     *
     * @default - No subject
     * @stability stable
     */
    readonly subject?: string;
}
/**
 * A Step Functions Task to publish messages to SNS topic.
 *
 * @stability stable
 */
export declare class SnsPublish extends sfn.TaskStateBase {
    private readonly props;
    private static readonly SUPPORTED_INTEGRATION_PATTERNS;
    /**
     * @stability stable
     */
    protected readonly taskMetrics: sfn.TaskMetricsConfig | undefined;
    /**
     * @stability stable
     */
    protected readonly taskPolicies: iam.PolicyStatement[] | undefined;
    private readonly integrationPattern;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: SnsPublishProps);
    /**
     * Provides the SNS Publish service integration task configuration
     */
    /**
     * @internal
     */
    protected _renderTask(): any;
}
